@@ -1,12 +1,12 @@
 /*
-** Copyright (C) 1991, 1997-2013,2017 Free Software Foundation, Inc.
+** Copyright 2017,2020 Thomas E. Dickey
+** Copyright 1997-2013,2017 Free Software Foundation, Inc.
 **
 ** This file is part of TACK.
 **
 ** TACK is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2, or (at your option)
-** any later version.
+** the Free Software Foundation, version 2.
 **
 ** TACK is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -21,7 +21,7 @@
 
 #include <tack.h>
 
-MODULE_ID("$Id: fun.c,v 1.26 2017/07/29 00:02:52 tom Exp $")
+MODULE_ID("$Id: fun.c,v 1.29 2020/02/02 16:31:05 tom Exp $")
 
 /*
  * Test the function keys on the terminal.  The code for echo tests
@@ -45,7 +45,6 @@ TestList funkey_test_list[] = {
     {MENU_LAST, 0, 0, 0, 0, 0, 0}
 };
 /* *INDENT-ON* */
-
 static void printer_on(TestList *, int *, int *);
 static void printer_mc0(TestList *, int *, int *);
 
@@ -851,14 +850,14 @@ tools_report(
 	    if (hex_display) {
 		ptext(hex_expand_to(&buf[i - 1], 3));
 	    } else {
-		tc_putch(ch | high_bit);
+		tc_putch((TC_PUTCH) (ch | high_bit));
 	    }
 	} else if (ch == '\n' || ch == '\r') {
 	    /* status report test */
 	    put_crlf();
 	    crp = 0;
 	} else if (crp++ < crx) {
-	    tc_putch(ch | high_bit);
+	    tc_putch((TC_PUTCH) (ch | high_bit));
 	} else {
 	    put_str(expand(&buf[i - 1]));
 	}
